@@ -6,7 +6,7 @@ use 5.020;
 use exact;
 use exact::class;
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 has acronyms             => 0;
 has sorting              => 1;
@@ -27,8 +27,8 @@ has _bibles => {
         [ 'Ruth',                  'Ru',   'Rut'                                                         ],
         [ '1 Samuel',              '1Sa',  '1Sm',     '1Sam'                                             ],
         [ '2 Samuel',              '2Sa',  '2Sm',     '2Sam'                                             ],
-        [ '1 Kings',               '1Ki',  '1Kg',     '1Kin'                                             ],
-        [ '2 Kings',               '2Ki',  '2Kg',     '2Kin'                                             ],
+        [ '1 Kings',               '1Ki',  '1Kg',     '1Kgs',                '1Kin'                      ],
+        [ '2 Kings',               '2Ki',  '2Kg',     '2Kgs',                '2Kin'                      ],
         [ '1 Chronicles',          '1Ch',  '1Cr',     '1Chr'                                             ],
         [ '2 Chronicles',          '2Ch',  '2Cr',     '2Chr'                                             ],
         [ 'Ezra',                  'Ezr'                                                                 ],
@@ -80,9 +80,9 @@ has _bibles => {
         [ '1 Timothy',             '1Ti',  '1Tm',     '1Tim'                                             ],
         [ '2 Timothy',             '2Ti',  '2Tm',     '2Tim'                                             ],
         [ 'Titus',                 'Ti',   'Tt'                                                          ],
-        [ 'Philemon',              'Phm',  'Phile'                                                       ],
+        [ 'Philemon',              'Phm',  'Phlm',    'Phile'                                            ],
         [ 'Hebrews',               'He',   'Heb'                                                         ],
-        [ 'James',                 'Jam',  'Jms'                                                         ],
+        [ 'James',                 'Jam',  'Jms',     'Jas'                                              ],
         [ '1 Peter',               '1Pt',  '1Pe',     '1Pet'                                             ],
         [ '2 Peter',               '2Pt',  '2Pe',     '2Pet'                                             ],
         [ '1 John',                '1Jn',  '1Jo',     '1Joh'                                             ],
@@ -102,8 +102,8 @@ has _bibles => {
         [ 'Ruth',                  'Ru',   'Rut'                                                         ],
         [ '1 Samuel',              '1Sa',  '1Sm',     '1Sam'                                             ],
         [ '2 Samuel',              '2Sa',  '2Sm',     '2Sam'                                             ],
-        [ '1 Kings',               '1Ki',  '1Kg',     '1Kin'                                             ],
-        [ '2 Kings',               '2Ki',  '2Kg',     '2Kin'                                             ],
+        [ '1 Kings',               '1Ki',  '1Kg',     '1Kgs',                '1Kin'                      ],
+        [ '2 Kings',               '2Ki',  '2Kg',     '2Kgs',                '2Kin'                      ],
         [ '1 Chronicles',          '1Ch',  '1Cr',     '1Chr'                                             ],
         [ '2 Chronicles',          '2Ch',  '2Cr',     '2Chr'                                             ],
         [ 'Esdras',                'Esd'                                                                 ],
@@ -160,9 +160,9 @@ has _bibles => {
         [ '1 Timothy',             '1Ti',  '1Tm',     '1Tim'                                             ],
         [ '2 Timothy',             '2Ti',  '2Tm',     '2Tim'                                             ],
         [ 'Titus',                 'Ti',   'Tt'                                                          ],
-        [ 'Philemon',              'Phm',  'Phile'                                                       ],
+        [ 'Philemon',              'Phm',  'Phlm',    'Phile'                                            ],
         [ 'Hebrews',               'He',   'Heb'                                                         ],
-        [ 'James',                 'Jam',  'Jms'                                                         ],
+        [ 'James',                 'Jam',  'Jms',     'Jas'                                              ],
         [ '1 Peter',               '1Pt',  '1Pe',     '1Pet'                                             ],
         [ '2 Peter',               '2Pt',  '2Pe',     '2Pet'                                             ],
         [ '1 John',                '1Jn',  '1Jo',     '1Joh'                                             ],
@@ -182,8 +182,8 @@ has _bibles => {
         [ 'Ruth',                  'Ru',   'Rut'                                                         ],
         [ '1 Samuel',              '1Sa',  '1Sm',     '1Sam'                                             ],
         [ '2 Samuel',              '2Sa',  '2Sm',     '2Sam'                                             ],
-        [ '1 Kings',               '1Ki',  '1Kg',     '1Kin'                                             ],
-        [ '2 Kings',               '2Ki',  '2Kg',     '2Kin'                                             ],
+        [ '1 Kings',               '1Ki',  '1Kg',     '1Kgs',                '1Kin'                      ],
+        [ '2 Kings',               '2Ki',  '2Kg',     '2Kgs',                '2Kin'                      ],
         [ '1 Chronicles',          '1Ch',  '1Cr',     '1Chr'                                             ],
         [ '2 Chronicles',          '2Ch',  '2Cr',     '2Chr'                                             ],
         [ 'Ezra',                  'Ezr'                                                                 ],
@@ -228,9 +228,9 @@ has _bibles => {
         [ '1 Timothy',             '1Ti',  '1Tm',     '1Tim'                                             ],
         [ '2 Timothy',             '2Ti',  '2Tm',     '2Tim'                                             ],
         [ 'Titus',                 'Ti',   'Tt'                                                          ],
-        [ 'Philemon',              'Phm',  'Phile'                                                       ],
+        [ 'Philemon',              'Phm',  'Phlm',    'Phile'                                            ],
         [ 'Hebrews',               'He',   'Heb'                                                         ],
-        [ 'James',                 'Jam',  'Jms'                                                         ],
+        [ 'James',                 'Jam',  'Jms',     'Jas'                                              ],
         [ '1 Peter',               '1Pt',  '1Pe',     '1Pet'                                             ],
         [ '2 Peter',               '2Pt',  '2Pe',     '2Pet'                                             ],
         [ '1 John',                '1Jn',  '1Jo',     '1Joh'                                             ],
@@ -250,8 +250,8 @@ has _bibles => {
         [ 'Ruth',                  'Ru',   'Rut',     'Ruth'                                             ],
         [ '1 Samuel',              '1Sa',  '1Sm',     '1Sam',                '1 Samuelis'                ],
         [ '2 Samuel',              '2Sa',  '2Sm',     '2Sam',                '2 Samuelis'                ],
-        [ '1 Kings',               '1Ki',  '1Kg',     '1Kin',                '1 Regum'                   ],
-        [ '2 Kings',               '2Ki',  '2Kg',     '2Kin',                '2 Regum'                   ],
+        [ '1 Kings',               '1Ki',  '1Kg',     '1Kgs',                '1Kin',         '1 Regum'   ],
+        [ '2 Kings',               '2Ki',  '2Kg',     '2Kgs',                '2Kin',         '2 Regum'   ],
         [ '1 Paralipomenon',       '1Pa',  '1Par',    '1 Paralipomenon'                                  ],
         [ '2 Paralipomenon',       '2Pa',  '2Par',    '2 Paralipomenon'                                  ],
         [ 'Esdras',                'Esd',  'Esdrae'                                                      ],
@@ -303,9 +303,9 @@ has _bibles => {
         [ '1 Timothy',             '1Ti',  '1Tm',     '1Tim',                '1 Timotheum'               ],
         [ '2 Timothy',             '2Ti',  '2Tm',     '2Tim',                '2 Timotheum'               ],
         [ 'Titus',                 'Ti',   'Tt',      'Titum'                                            ],
-        [ 'Philemon',              'Phm',  'Phile',   'Philemonem'                                       ],
+        [ 'Philemon',              'Phm',  'Phlm',    'Phile',               'Philemonem'                ],
         [ 'Hebrews',               'He',   'Heb',     'Hebraeos'                                         ],
-        [ 'James',                 'Jam',  'Jms',     'Iacobi'                                           ],
+        [ 'James',                 'Jam',  'Jms',     'Jas',                 'Iacobi'                    ],
         [ '1 Peter',               '1Pt',  '1Pe',     '1Pet',                '1 Petri'                   ],
         [ '2 Peter',               '2Pt',  '2Pe',     '2Pet',                '2 Petri'                   ],
         [ '1 John',                '1Jn',  '1Jo',     '1Joh',                '1 Ioannis'                 ],
@@ -1581,7 +1581,7 @@ Bible::Reference - Simple Bible reference parser, tester, and canonicalizer
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =for markdown [![test](https://github.com/gryphonshafer/Bible-Reference/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bible-Reference/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Bible-Reference/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bible-Reference)
